==> OperonHumanV3.db_2.0.2.tar.gz: OperonHumanV3.db/man/OperonHumanV3_dbconn.Rd <==
\name{OperonHumanV3_dbconn}

\alias{OperonHumanV3_dbconn}
\alias{OperonHumanV3_dbfile}
\alias{OperonHumanV3_dbschema}
\alias{OperonHumanV3_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  OperonHumanV3_dbconn()
  OperonHumanV3_dbfile()
  OperonHumanV3_dbschema(file="", show.indices=FALSE)
  OperonHumanV3_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{OperonHumanV3_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{OperonHumanV3_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{OperonHumanV3_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{OperonHumanV3_dbschema} prints the schema definition of the
  package annotation DB.

  \code{OperonHumanV3_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{OperonHumanV3_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{OperonHumanV3_dbfile}: a character string with the path to the
  package annotation DB.

  \code{OperonHumanV3_dbschema}: none (invisible \code{NULL}).

  \code{OperonHumanV3_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(OperonHumanV3_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by OperonHumanV3_dbconn() was created with:
  dbConnect(SQLite(), dbname=OperonHumanV3_dbfile(), cache_size=64000, synchronous=0)

  OperonHumanV3_dbschema()

  OperonHumanV3_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> OperonHumanV3.db_2.4.1.tar.gz: OperonHumanV3.db/man/OperonHumanV3_dbconn.Rd <==

\name{OperonHumanV3_dbconn}

\alias{OperonHumanV3_dbconn}
\alias{OperonHumanV3_dbfile}
\alias{OperonHumanV3_dbschema}
\alias{OperonHumanV3_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  OperonHumanV3_dbconn()
  OperonHumanV3_dbfile()
  OperonHumanV3_dbschema(file="", show.indices=FALSE)
  OperonHumanV3_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{OperonHumanV3_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{OperonHumanV3_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{OperonHumanV3_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{OperonHumanV3_dbschema} prints the schema definition of the
  package annotation DB.

  \code{OperonHumanV3_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{OperonHumanV3_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{OperonHumanV3_dbfile}: a character string with the path to the
  package annotation DB.

  \code{OperonHumanV3_dbschema}: none (invisible \code{NULL}).

  \code{OperonHumanV3_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(OperonHumanV3_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by OperonHumanV3_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=OperonHumanV3_dbfile(), cache_size=64000,
  synchronous=0)

  OperonHumanV3_dbschema()

  OperonHumanV3_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
